<?php

namespace Bixo\Collection\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Collection\Events\CollectionsAction as CollectionsActionEvent;
use Bixo\Collection\Notifications\CollectionsAction as CollectionsActionNotification;
use Litepie\Actions\Concerns\AsAction;

class CollectionsAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the CollectionsActionEvent.
     *
     * @param   CollectionsActionEvent  $event
     * @return mixed
     */
    public function handle(CollectionsActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $collections.
     *
     * @param   CollectionsActionEvent  $event
     * @return void
     */
    public function create(CollectionsActionEvent $event)
    {
        $client = $event->collections->client;
        Notification::send($client, new CollectionsActionNotification($event));
    }

    /**
     * Handle the CollectionsActionEvent as a listener.
     *
     * @param   CollectionsActionEvent  $event
     * @return mixed
     */
    public function asListener(CollectionsActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   CollectionsActionEvent  $event
     * @return bool
     */
    private function isAllowed(CollectionsActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
