<?php

namespace Bixo\Collection\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Collection\Events\CollectionsWorkflow as CollectionsWorkflowEvent;
use Bixo\Collection\Notifications\CollectionsWorkflow as CollectionsWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class CollectionsWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(CollectionsWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $collections is submitted.
     *
     * @param CollectionsWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(CollectionsWorkflowEvent $event)
    {
        $client = $event->collections->client;
        Notification::send($client, new CollectionsWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $collections is published.
     *
     * @param CollectionsWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(CollectionsWorkflowEvent $event)
    {
        $client = $event->collections->client;
        Notification::send($client, new CollectionsWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $collections is approved.
     *
     * @param CollectionsWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(CollectionsWorkflowEvent $event)
    {
        $client = $event->collections->client;
        Notification::send($client, new CollectionsWorkflowNotification($event));
    }

    /**
     * Handles the $collections workflow event as a listener.
     *
     * @param CollectionsWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(CollectionsWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
